@@ -1,10 +1,9 @@
 package Koha::Contrib::Tamil::Logger;
 # ABSTRACT: Base class pour logger
-$Koha::Contrib::Tamil::Logger::VERSION = '0.043';
+$Koha::Contrib::Tamil::Logger::VERSION = '0.044';
 
 use Moose;
 use Modern::Perl;
-use utf8;
 use FindBin qw( $Bin );
 use Log::Dispatch;
 use Log::Dispatch::Screen;
@@ -15,7 +14,7 @@ use Log::Dispatch::File;
 has log_filename => (
     is => 'rw',
     isa => 'Str',
-    default => "./koha-contri-tamil.log",
+    default => "./koha-contrib-tamil.log",
 );
 
 has log => (
@@ -33,7 +32,6 @@ has log => (
             name      => 'file1',
             min_level => 'debug',
             filename  => $self->log_filename, 
-            binmode   => ':encoding(UTF-8)',
         ) );
         return $log;
     }
@@ -58,7 +56,7 @@ Koha::Contrib::Tamil::Logger - Base class pour logger
 
 =head1 VERSION
 
-version 0.043
+version 0.044
 
 =head1 SYNOPSYS
 
